@@ -12,12 +12,12 @@ from flask import current_app
 from ..daemon.client import DaemonClient
 from ..daemon.exceptions import DaemonUnavailableError
 
-from . import api
+from . import api_routing
 from .user import admin_only
 from .exceptions import ServerError
 
 
-@api.route("/startScan.view", methods=["GET", "POST"])
+@api_routing("/startScan")
 @admin_only
 def startScan():
     try:
@@ -28,14 +28,14 @@ def startScan():
         raise ServerError(str(e))
     return request.formatter(
         "scanStatus",
-        dict(
-            scanning="true" if scanned is not None else "false",
-            count=scanned if scanned is not None else 0,
-        ),
+        {
+            "scanning": scanned is not None,
+            "count": scanned or 0,
+        },
     )
 
 
-@api.route("/getScanStatus.view", methods=["GET", "POST"])
+@api_routing("/getScanStatus")
 @admin_only
 def getScanStatus():
     try:
@@ -46,8 +46,8 @@ def getScanStatus():
         raise ServerError(str(e))
     return request.formatter(
         "scanStatus",
-        dict(
-            scanning="true" if scanned is not None else "false",
-            count=scanned if scanned is not None else 0,
-        ),
+        {
+            "scanning": scanned is not None,
+            "count": scanned or 0,
+        },
     )
