@@ -1,5 +1,3 @@
-# coding: utf-8
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
@@ -38,7 +36,7 @@ CacheEntry = namedtuple("CacheEntry", ["size", "expires"])
 NULL_ENTRY = CacheEntry(0, 0)
 
 
-class Cache(object):
+class Cache:
     """Provides a common interface for caching files to disk"""
 
     # Modeled after werkzeug.contrib.cache.FileSystemCache
@@ -159,9 +157,10 @@ class Cache(object):
                     self._make_space(size, key=key)
                 os.replace(f.name, self._filepath(key))
                 self._record_file(key, size)
-        except:
+        except BaseException:
             f.close()
-            os.remove(f.name)
+            with contextlib.suppress(OSError):
+                os.remove(f.name)
             raise
 
     def set(self, key, value):
@@ -182,9 +181,21 @@ class Cache(object):
         ...     print(x)
         """
         with self.set_fileobj(key) as f:
-            for data in gen_function():
-                f.write(data)
-                yield data
+            gen = gen_function()
+            try:
+                for data in gen:
+                    f.write(data)
+                    yield data
+            except GeneratorExit:
+                # Try to stop the generator but check it still wants to yield data.
+                # If it does allow caching of this data without forwarding it
+                try:
+                    f.write(gen.throw(GeneratorExit))
+                    for data in gen:
+                        f.write(data)
+                except StopIteration:
+                    # We stopped just at the end of the generator
+                    pass
 
     def get(self, key):
         """Return the path to the file where the cached data is stored"""
