@@ -67,12 +67,13 @@ CREATE TABLE IF NOT EXISTS user (
 CREATE INDEX IF NOT EXISTS index_user_last_play_id_fk ON user(last_play_id);
 
 CREATE TABLE IF NOT EXISTS client_prefs (
-    user_id CHAR(36) NOT NULL,
+    user_id CHAR(36) NOT NULL REFERENCES user,
     client_name VARCHAR(32) NOT NULL,
     format VARCHAR(8),
     bitrate INTEGER,
     PRIMARY KEY (user_id, client_name)
 );
+CREATE INDEX IF NOT EXISTS index_client_prefs_user_id_fk ON client_prefs(user_id);
 
 CREATE TABLE IF NOT EXISTS starred_folder (
     user_id CHAR(36) NOT NULL REFERENCES user,
