@@ -1,7 +1,7 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2021 Alban 'spl0k' Féron
+# Copyright (C) 2021-2023 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
@@ -12,7 +12,7 @@ from ._base import BaseServer
 
 class WaitressServer(BaseServer):
     def _build_kwargs(self):
-        rv = {"app": self._app}
+        rv = {"app": self._load_app()}
 
         if self._host is not None:
             rv["host"] = self._host
