@@ -9,13 +9,12 @@ import logging
 import os.path
 import time
 
-from pony.orm import db_session
 from threading import Thread, Condition, Timer
 from watchdog.observers import Observer
 from watchdog.events import PatternMatchingEventHandler
 
 from . import covers
-from .db import Folder
+from .db import Folder, open_connection, close_connection
 from .scanner import Scanner
 
 OP_SCAN = 1
@@ -46,16 +45,9 @@ class SupysonicWatcherEventHandler(PatternMatchingEventHandler):
         logger.debug("File created: '%s'", event.src_path)
 
         op = OP_SCAN | FLAG_CREATE
-        if not covers.is_valid_cover(event.src_path):
-            self.queue.put(event.src_path, op)
-
-            dirname = os.path.dirname(event.src_path)
-            with db_session:
-                folder = Folder.get(path=dirname)
-            if folder is None:
-                self.queue.put(dirname, op | FLAG_COVER)
-        else:
-            self.queue.put(event.src_path, op | FLAG_COVER)
+        if covers.is_valid_cover(event.src_path):
+            op |= FLAG_COVER
+        self.queue.put(event.src_path, op)
 
     def on_deleted(self, event):
         logger.debug("File deleted: '%s'", event.src_path)
@@ -155,6 +147,7 @@ class ScannerProcessingQueue(Thread):
                     continue
 
             logger.debug("Instantiating scanner")
+            open_connection()
             scanner = Scanner()
 
             item = self.__next_item()
@@ -167,6 +160,7 @@ class ScannerProcessingQueue(Thread):
                 item = self.__next_item()
 
             scanner.prune()
+            close_connection()
             logger.debug("Freeing scanner")
 
     def __process_regular_item(self, scanner, item):
@@ -290,9 +284,8 @@ class SupysonicWatcher:
         self.__observer = Observer()
         self.__handler.queue = self.__queue
 
-        with db_session:
-            for folder in Folder.select(lambda f: f.root):
-                self.add_folder(folder)
+        for folder in Folder.select().where(Folder.root):
+            self.add_folder(folder)
 
         logger.info("Starting watcher")
         self.__queue.start()
