@@ -1,15 +1,13 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2017-2018 Alban 'spl0k' Féron
+# Copyright (C) 2017-2022 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
 import unittest
 import uuid
 
-from pony.orm import db_session
-
 from supysonic.db import Folder, Artist, Album, Track, Playlist, User
 
 from .frontendtestbase import FrontendTestBase
@@ -19,28 +17,28 @@ class PlaylistTestCase(FrontendTestBase):
     def setUp(self):
         super().setUp()
 
-        with db_session:
-            folder = Folder(name="Root", path="tests/assets", root=True)
-            artist = Artist(name="Artist!")
-            album = Album(name="Album!", artist=artist)
+        folder = Folder.create(name="Root", path="tests/assets", root=True)
+        artist = Artist.create(name="Artist!")
+        album = Album.create(name="Album!", artist=artist)
 
-            track = Track(
-                path="tests/assets/23bytes",
-                title="23bytes",
-                artist=artist,
-                album=album,
-                folder=folder,
-                root_folder=folder,
-                duration=2,
-                disc=1,
-                number=1,
-                bitrate=320,
-                last_modification=0,
-            )
+        track = Track.create(
+            path="tests/assets/23bytes",
+            title="23bytes",
+            artist=artist,
+            album=album,
+            folder=folder,
+            root_folder=folder,
+            duration=2,
+            disc=1,
+            number=1,
+            bitrate=320,
+            last_modification=0,
+        )
 
-            playlist = Playlist(name="Playlist!", user=User.get(name="alice"))
-            for _ in range(4):
-                playlist.add(track)
+        playlist = Playlist.create(name="Playlist!", user=User.get(name="alice"))
+        for _ in range(4):
+            playlist.add(track)
+        playlist.save()
 
         self.playlistid = playlist.id
 
@@ -80,8 +78,7 @@ class PlaylistTestCase(FrontendTestBase):
         )
         self.assertNotIn("updated", rv.data)
         self.assertIn("Missing", rv.data)
-        with db_session:
-            self.assertEqual(Playlist[self.playlistid].name, "Playlist!")
+        self.assertEqual(Playlist[self.playlistid].name, "Playlist!")
 
         rv = self.client.post(
             "/playlist/" + str(self.playlistid),
@@ -90,10 +87,9 @@ class PlaylistTestCase(FrontendTestBase):
         )
         self.assertIn("updated", rv.data)
         self.assertNotIn("not allowed", rv.data)
-        with db_session:
-            playlist = Playlist[self.playlistid]
-            self.assertEqual(playlist.name, "abc")
-            self.assertTrue(playlist.public)
+        playlist = Playlist[self.playlistid]
+        self.assertEqual(playlist.name, "abc")
+        self.assertTrue(playlist.public)
 
     def test_delete(self):
         self._login("bob", "B0b")
@@ -107,8 +103,7 @@ class PlaylistTestCase(FrontendTestBase):
             "/playlist/del/" + str(self.playlistid), follow_redirects=True
         )
         self.assertIn("not allowed", rv.data)
-        with db_session:
-            self.assertEqual(Playlist.select().count(), 1)
+        self.assertEqual(Playlist.select().count(), 1)
         self._logout()
 
         self._login("alice", "Alic3")
@@ -116,8 +111,7 @@ class PlaylistTestCase(FrontendTestBase):
             "/playlist/del/" + str(self.playlistid), follow_redirects=True
         )
         self.assertIn("deleted", rv.data)
-        with db_session:
-            self.assertEqual(Playlist.select().count(), 0)
+        self.assertEqual(Playlist.select().count(), 0)
 
 
 if __name__ == "__main__":
